[v2,4/4] test_dmadev: increase iterations of capacity test case

Message ID 20220111134105.1007191-5-bruce.richardson@intel.com (mailing list archive)
State Accepted, archived
Delegated to: Thomas Monjalon
Headers
Series fixes for dma/idxd |

Checks

Context Check Description
ci/checkpatch success coding style OK
ci/github-robot: build success github build: passed
ci/Intel-compilation success Compilation OK
ci/intel-Testing success Testing PASS
ci/iol-broadcom-Performance success Performance Testing PASS
ci/iol-mellanox-Performance success Performance Testing PASS
ci/iol-broadcom-Functional success Functional Testing PASS
ci/iol-intel-Performance success Performance Testing PASS
ci/iol-intel-Functional success Functional Testing PASS
ci/iol-aarch64-unit-testing success Testing PASS
ci/iol-x86_64-compile-testing success Testing PASS
ci/iol-abi-testing warning Testing issues
ci/iol-aarch64-compile-testing success Testing PASS
ci/iol-x86_64-unit-testing success Testing PASS

Commit Message

Bruce Richardson Jan. 11, 2022, 1:41 p.m. UTC
  To ensure we catch any bugs in calculation due to wrap-around of the id
values, increase the number of iterations of the burst_capacity test.

Signed-off-by: Bruce Richardson <bruce.richardson@intel.com>
---
 app/test/test_dmadev.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)
  

Comments

Kevin Laatz Jan. 11, 2022, 4:50 p.m. UTC | #1
On 11/01/2022 13:41, Bruce Richardson wrote:
> To ensure we catch any bugs in calculation due to wrap-around of the id
> values, increase the number of iterations of the burst_capacity test.
>
> Signed-off-by: Bruce Richardson <bruce.richardson@intel.com>
> ---
>   app/test/test_dmadev.c | 7 ++++---
>   1 file changed, 4 insertions(+), 3 deletions(-)
>

Acked-by: Kevin Laatz <kevin.laatz@intel.com>
  

Patch

diff --git a/app/test/test_dmadev.c b/app/test/test_dmadev.c
index b206db27ae..db5aff701c 100644
--- a/app/test/test_dmadev.c
+++ b/app/test/test_dmadev.c
@@ -686,10 +686,11 @@  test_burst_capacity(int16_t dev_id, uint16_t vchan)
 	/* to test capacity, we enqueue elements and check capacity is reduced
 	 * by one each time - rebaselining the expected value after each burst
 	 * as the capacity is only for a burst. We enqueue multiple bursts to
 	 * fill up half the ring, before emptying it again. We do this twice to
 	 * ensure that we get to test scenarios where we get ring wrap-around
 	 */
-	for (iter = 0; iter < 2; iter++) {
+	for (iter = 0; iter < 2 * (((int)UINT16_MAX + 1) / ring_space); iter++) {
 		for (i = 0; i < (ring_space / (2 * CAP_TEST_BURST_SIZE)) + 1; i++) {
 			cap = rte_dma_burst_capacity(dev_id, vchan);
@@ -686,10 +686,11 @@  test_burst_capacity(int16_t dev_id, uint16_t vchan)
 	 * by one each time - rebaselining the expected value after each burst
 	 * as the capacity is only for a burst. We enqueue multiple bursts to
-	 * fill up half the ring, before emptying it again. We do this twice to
-	 * ensure that we get to test scenarios where we get ring wrap-around
+	 * fill up half the ring, before emptying it again. We do this multiple
+	 * times to ensure that we get to test scenarios where we get ring
+	 * wrap-around and wrap-around of the ids returned (at UINT16_MAX).
 	 */